pub fn read_str_ref(rd: &[u8]) -> Result<&[u8], DecodeStringError<'_>>
👎Deprecated since 0.8.6:

useless, use read_str_from_slice instead

Attempts to read and decode a string value from the reader, returning a borrowed slice from it.