Function rmp::encode::write_array_len
source · [−]Expand description
Encodes and attempts to write the most efficient array length implementation to the given write, returning the marker used.
Errors
This function will return ValueWriteError on any I/O error occurred while writing either the
marker or the data.