Function rmp::encode::write_map_len
source · [−]Expand description
Encodes and attempts to write the most efficient map length implementation to the given write, returning the marker used.
Errors
This function will return ValueWriteError on any I/O error occurred while writing either the
marker or the data.