Encodes and attempts to write the most efficient string binary representation to the
given Write.
Errors
This function will return ValueWriteError on any I/O error occurred while writing either the
marker or the data.
Encodes and attempts to write the most efficient string binary representation to the
given Write.
This function will return ValueWriteError on any I/O error occurred while writing either the
marker or the data.